..
  NOTE: This RST file was generated by `make examples`.
  Do not edit it directly.
  See docs/source/examples/example_doc_generator.py

Manual Vbox Example
===============================================================================

An example which demonstrates the manual specification of a ``vbox``.

This example demonstrates how one would manually define the constraints
for a ``vbox`` style layout. In fact, the ``vbox`` layout helper generates
the primitive constraints in a fashion very similar to this example.
The intent of this example is to demonstrate that all of the layout
helper functions can be distilled down to a list of primitive
constraints.

.. TIP:: To see this example in action, download it from
 :download:`manual_vbox <../../../examples/layout/advanced/manual_vbox.enaml>`
 and run::

   $ enaml-run manual_vbox.enaml


Screenshot
-------------------------------------------------------------------------------

.. image:: images/ex_manual_vbox.png

Example Enaml Code
-------------------------------------------------------------------------------
.. literalinclude:: ../../../examples/layout/advanced/manual_vbox.enaml
    :language: enaml
